@@ -7,6 +7,9 @@
 
 #include "kaccountsdplugin.h"
 
+namespace KAccounts
+{
+
 KAccountsDPlugin::KAccountsDPlugin(QObject *parent, const QVariantList & /*args*/)
     : QObject(parent)
 {
@@ -15,3 +18,5 @@ KAccountsDPlugin::KAccountsDPlugin(QObject *parent, const QVariantList & /*args*
 KAccountsDPlugin::~KAccountsDPlugin()
 {
 }
+
+};
